<?php
if (!defined('grasshoppers.php')) {
    exit;
}
/***************************/
/* Add plugin link on menu */
function ghcod_settings_menu()
{
    add_options_page(
        'Grasshoppers COD', //Tab Title
        'Grasshoppers COD', //Menu Name
        'manage_options',
        'grasshoppers-cod', //Link
        'ghcod_config_page' //Page function name
    );
}
/***************************/
/* Add plugin settings link */
function grasshoppers_cod_settings_link( $links ) {
	$links[] = '<a href="' .
		admin_url( 'options-general.php?page=grasshoppers-cod' ) .
		'">' . __('Settings') . '</a>';
	return $links;
}
/***************************/
/* Add plugin link on menu */
function ghcod_config_page()
{ ?>
    <div id="gh-general" class="wrap">
        <h2>Grasshoppers COD Settings</h2>
        <form name="ghcod_options_form_settings_api" method="post" action="options.php">

            <?php settings_fields('ghcod_settings'); ?>
            <?php do_settings_sections('ghcod_settings_section'); ?>
            <input type="submit" value="Submit" class="button-primary" />
        </form>
    </div>
<?php }
/***************************/
/* Display options fields */
function ghcod_admin_init()
{
    register_setting(
        'ghcod_settings',
        'ghcod_options',
        'ghcod_validate_options'
    );

    add_settings_section(
        'ghcod_main_section',
        'Main Settings',
        'ghcod_main_setting_section_callback',
        'ghcod_settings_section'
    );
 
    add_settings_field(
        'ghcod_live_cooporate_id',
        'Live Cooporate ID',
        'ghcod_cooporate_id',
        'ghcod_settings_section',
        'ghcod_main_section',
        array('name' => 'ghcod_live_cooporate_id')
    );
    
    add_settings_field(
        'ghcod_pickup_street',
        'Pickup Street',
        'ghcod_cooporate_id',
        'ghcod_settings_section',
        'ghcod_main_section',
        array('name' => 'ghcod_pickup_street')
    );
    
    add_settings_field(
        'ghcod_pickup_city',
        'Pickup City',
        'ghcod_cooporate_id',
        'ghcod_settings_section',
        'ghcod_main_section',
        array('name' => 'ghcod_pickup_city')
    );
    
    add_settings_field(
        'ghcod_pickup_zipcode',
        'Pickup ZipCode',
        'ghcod_cooporate_id',
        'ghcod_settings_section',
        'ghcod_main_section',
        array('name' => 'ghcod_pickup_zipcode')
    );
    
    $available_payment_methods = WC()->payment_gateways->get_available_payment_gateways();

    foreach( $available_payment_methods as $method ) {
	    
	    add_settings_field(
        str_replace(' ', '_', $method->get_title()),
        'Enable for '.$method->get_title(),
        'ghcod_sandbox_mode',
        'ghcod_settings_section',
        'ghcod_main_section',
        array('name' => str_replace(' ', '_', $method->get_title()))
    );
    
    }
}
/***************************/
/* Text */
function ghcod_main_setting_section_callback( $file = 'grasshoppers-cod' )
{ ?>

    <p>Just reach us via <a href="mailto:hello@primeone.global">hello@primeone.global</a>.<br><b>NOTE: See /wp-content/uploads/grasshoppers-cod.log for Log file.</b></p>
<?php }
/***************************/
/* Get cooporate id */
function ghcod_cooporate_id($data = array())
{
    extract($data);
    $options = ghcod_get_options();
?>
    <input type="text" name="ghcod_options[<?php echo esc_html($name); ?>]" value="<?php echo esc_html($options[$name]); ?>" />
    <br />
<?php }
/***************************/
/* Get sandbox status */
function ghcod_sandbox_mode($data = array())
{
    extract($data);
    $options = ghcod_get_options();
    
?>
    <input type="checkbox" name="ghcod_options[<?php echo esc_html($name); ?>]" <?php checked($options[$name] == 'on'); ?> />
<?php }
/***************************/
/* Validate options */
function ghcod_validate_options($input)
{
    foreach (array('ghcod_cooporate_id') as $option_name) {
        if (isset($input[$option_name])) {
            $input[$option_name] =
                sanitize_text_field($input[$option_name]);
        }
    }
    return $input;
}
/***************************/
/* Create log data */
if ( ! function_exists( 'plugin_log' ) ) {
    function plugin_log( $entry, $mode = 'a', $file = 'grasshoppers-cod' ) { 
      // Get WordPress uploads directory.
      $upload_dir = wp_upload_dir();
      $upload_dir = $upload_dir['basedir'];
      // If the entry is array, json_encode.
      if ( is_array( $entry ) ) { 
        $entry = json_encode( $entry ); 
      } 
      // Write the log file.
      $file  = $upload_dir . '/' . $file . '.log';
      $file  = fopen( $file, $mode );
      $bytes = fwrite( $file, current_time( 'mysql' ) . "::" . $entry . "\n" ); 
      fclose( $file ); 
      return $bytes;
    }
    /* Usage */
    /*
        // Append an entry to the uploads/grasshoppers-cod.log file.
        plugin_log( 'Something happened.' );
        // Append an array entry to the uploads/grasshoppers-cod.log file.
        plugin_log( ['new_user' => 'benmarshall' ] );
        // Write an entry to the uploads/grasshoppers-cod.log file, deleting the existing entries.
        plugin_log( 'Awesome sauce.', 'w' );
        // Append an entry to a different log file in the uploads directory.
        plugin_log( 'Simple stuff.', 'a', 'simple-stuff' );
    */
  }
/***************************/